@@ -29,6 +29,9 @@ pub type time_t = i64;
 /// The type of a file’s user ID.
 pub type uid_t = u32;
 
+/// The type of user file flags
+pub type flag_t = u32;
+
 /// The file’s base type, which gets displayed in the very first column of the
 /// details output.
 ///
@@ -79,6 +82,7 @@ pub struct Permissions {
 /// The file's `FileAttributes` field, available only on Windows.
 #[derive(Copy, Clone)]
 #[rustfmt::skip]
+#[cfg(windows)]
 pub struct Attributes {
     pub archive:         bool,
     pub directory:       bool,
@@ -274,3 +278,7 @@ impl Default for SubdirGitRepo {
         }
     }
 }
+
+/// The user file flags on the file. This will only ever be a number;
+/// looking up the flags is done in the `display` module.
+pub struct Flags(pub flag_t);
